Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/irorun/__init__.py | (no function) | 0 | 0 | 0 | 100%
src/irorun/cli.py | main | 4 | 2 | 0 | 50%
src/irorun/cli.py | load_config | 12 | 3 | 0 | 75%
src/irorun/cli.py | init | 32 | 32 | 0 | 0%
src/irorun/cli.py | check | 8 | 0 | 0 | 100%
src/irorun/cli.py | check_upgrade | 6 | 6 | 0 | 0%
src/irorun/cli.py | check_codestyle | 3 | 3 | 0 | 0%
src/irorun/cli.py | format | 3 | 3 | 0 | 0%
src/irorun/cli.py | gen_config | 9 | 9 | 0 | 0%
src/irorun/cli.py | document | 1 | 1 | 0 | 0%
src/irorun/cli.py | (no function) | 30 | 2 | 0 | 93%
src/irorun/helpers.py | change_dir | 5 | 0 | 0 | 100%
src/irorun/helpers.py | run_command | 5 | 0 | 0 | 100%
src/irorun/helpers.py | add_dependencies | 5 | 0 | 0 | 100%
src/irorun/helpers.py | create_poetry_project | 6 | 0 | 0 | 100%
src/irorun/helpers.py | create_uv_project | 7 | 0 | 0 | 100%
src/irorun/helpers.py | create_virtualenv_project | 12 | 0 | 0 | 100%
src/irorun/helpers.py | create_subdirectories | 5 | 0 | 0 | 100%
src/irorun/helpers.py | (no function) | 20 | 0 | 0 | 100%
src/irorun/logger_setup.py | TyperLoggerHandler.emit | 16 | 6 | 0 | 62%
src/irorun/logger_setup.py | setup_logging | 7 | 4 | 0 | 43%
src/irorun/logger_setup.py | get_logger | 1 | 1 | 0 | 0%
src/irorun/logger_setup.py | (no function) | 8 | 0 | 0 | 100%
Total |  | 205 | 72 | 0 | 65%

No items found using the specified filter.